<?php

declare(strict_types=1);

namespace Drupal\rift\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\media\MediaInterface;
use Drupal\rift\RiftPicture;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for Responsive Image Formatter tools UI routes.
 */
final class RiftEndpointController implements ContainerInjectionInterface {

  /**
   * The controller constructor.
   */
  public function __construct(
    private readonly RiftPicture $riftPicture,
    private readonly ConfigFactoryInterface $configFactory,
    private readonly RendererInterface $renderer,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('rift.picture'),
      $container->get('config.factory'),
      $container->get('renderer'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke(MediaInterface $media) {
    $settings = $this->configFactory->get('rift.settings');
    $config = $settings->get('config');
    $view_modes = $settings->get('view_modes');
    $output = [];
    foreach ($view_modes as $key => $view_mode) {
      $runtime_config = $config;
      foreach ($view_mode as $k => $v) {
        $runtime_config[$k] = $v;
      }
      $build = $this->riftPicture->responsivePicture($media, $runtime_config);
      $output_string = $this->renderer->render($build);
      $runtime_config['url_generation_strategy'] = 'dummyimage';
      $build = $this->riftPicture->responsivePicture($media, $runtime_config);
      $placeholder_string = $this->renderer->render($build);
      $output['view_modes'][$key] = [
        'html' => $output_string,
        'placeholder' => $placeholder_string,
      ];
    }
    return new JsonResponse($output);
  }

}
